# mm-kermac
> Dynamically compiled hyper semirings for Pytorch using PTX Inject and Stack PTX

## Installation
```bash
pip install mm-kermac
```

## TODO
    * Better Docs
    * Benchmarks

## License
This project is licensed under the MIT License - see the [LICENSE](LICENSE) file for details.

## Citation
If you use this software in your work, please cite it using the following BibTeX entry (generated from the [CITATION.cff](CITATION.cff) file):
```bibtex
@software{Durham_mm-kermac_2025,
  author       = {Durham, Charlie},
  title        = {mm-kermac: PTX Inject and Stack PTX for Python},
  version      = {0.1.1},
  date-released = {2025-10-19},
  url          = {https://github.com/MetaMachines/mm-kermac-py}
}
```